@@ -2,13 +2,25 @@ import pika
 import os
 import msgpack
 from pika.spec import PERSISTENT_DELIVERY_MODE, TRANSIENT_DELIVERY_MODE, BasicProperties
+from pika.exceptions import AMQPConnectionError
 from typing import Protocol, Optional
 from abc import ABC, abstractmethod
 from . import Loggable
 from contextlib import contextmanager
 import logging
 
-__all__ = ["BaseProducer", "BlockingProducer", "PikaChannel"]
+__all__ = ["BaseProducer", "BlockingProducer", "PikaChannel", "ConnectionError"]
+
+
+class ConnectionError(Exception):
+    def __init__(self, inner):
+        self.inner = inner
+
+    def __repr__(self):
+        return repr(self.inner)
+
+    def __str__(self):
+        return str(self.inner)
 
 
 class PikaChannel(Protocol):
@@ -107,10 +119,13 @@ class BlockingProducer(BaseProducer):
 
     @contextmanager
     def __connect(self):
-        with pika.BlockingConnection(pika.URLParameters(self.url)) as connection:
-            self._connection = connection
-            self._channel = self._connection.channel()
-            yield
+        try:
+            with pika.BlockingConnection(pika.URLParameters(self.url)) as connection:
+                self._connection = connection
+                self._channel = self._connection.channel()
+                yield
+        except AMQPConnectionError as e:
+            raise ConnectionError(e)
 
     def queue_declare(self, queue, **kwargs):
         with self.__connect():
